summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrett Chabot <brettchabot@google.com>2013-12-04 11:50:09 -0800
committerBrett Chabot <brettchabot@google.com>2014-01-16 18:44:04 -0800
commitfdc820f21e1b07ba7e148936037767e0daf8375d (patch)
treec7c8f2c7a4353ea32b302a2cb8d8a00f5a8e03c6
parent790a18950902fadde82a1102c5aabcd40be91b93 (diff)
downloadtesting-fdc820f21e1b07ba7e148936037767e0daf8375d.tar.gz
DO NOT MERGE. Cherry pick 'Change android-test-lib package namespace to android.support.test'
Also move private API classes to internal package Bug: 10749552 Change-Id: Ic12343763680df63997951cfa8a9688f3153dab7
-rw-r--r--androidtestlib/Android.mk50
-rw-r--r--androidtestlib/README1
-rw-r--r--support/Android.mk94
-rw-r--r--support/src/android/support/test/BundleTest.java (renamed from androidtestlib/src/com/android/test/BundleTest.java)2
-rw-r--r--support/src/android/support/test/InjectBundle.java (renamed from androidtestlib/src/com/android/test/InjectBundle.java)2
-rw-r--r--support/src/android/support/test/InjectContext.java (renamed from androidtestlib/src/com/android/test/InjectContext.java)2
-rw-r--r--support/src/android/support/test/InjectInstrumentation.java (renamed from androidtestlib/src/com/android/test/InjectInstrumentation.java)2
-rw-r--r--support/src/android/support/test/internal/package.html5
-rw-r--r--support/src/android/support/test/internal/runner/AndroidRunnerBuilder.java (renamed from androidtestlib/src/com/android/test/runner/AndroidRunnerBuilder.java)6
-rw-r--r--support/src/android/support/test/internal/runner/ClassPathScanner.java (renamed from androidtestlib/src/com/android/test/runner/ClassPathScanner.java)2
-rw-r--r--support/src/android/support/test/internal/runner/TestLoader.java (renamed from androidtestlib/src/com/android/test/runner/TestLoader.java)2
-rw-r--r--support/src/android/support/test/internal/runner/TestRequest.java (renamed from androidtestlib/src/com/android/test/runner/TestRequest.java)2
-rw-r--r--support/src/android/support/test/internal/runner/TestRequestBuilder.java (renamed from androidtestlib/src/com/android/test/runner/TestRequestBuilder.java)10
-rw-r--r--support/src/android/support/test/internal/runner/junit3/AndroidJUnit3Builder.java (renamed from androidtestlib/src/com/android/test/runner/junit3/AndroidJUnit3Builder.java)4
-rw-r--r--support/src/android/support/test/internal/runner/junit3/AndroidJUnit3ClassRunner.java (renamed from androidtestlib/src/com/android/test/runner/junit3/AndroidJUnit3ClassRunner.java)2
-rw-r--r--support/src/android/support/test/internal/runner/junit3/AndroidTestSuite.java (renamed from androidtestlib/src/com/android/test/runner/junit3/AndroidTestSuite.java)4
-rw-r--r--support/src/android/support/test/internal/runner/junit3/NoExecTestResult.java (renamed from androidtestlib/src/com/android/test/runner/junit3/NoExecTestResult.java)2
-rw-r--r--support/src/android/support/test/internal/runner/junit3/NonExecutingJUnit3ClassRunner.java (renamed from androidtestlib/src/com/android/test/runner/junit3/NonExecutingJUnit3ClassRunner.java)2
-rw-r--r--support/src/android/support/test/internal/runner/junit3/package.html5
-rw-r--r--support/src/android/support/test/internal/runner/junit4/AndroidJUnit4Builder.java (renamed from androidtestlib/src/com/android/test/runner/junit4/AndroidJUnit4Builder.java)6
-rw-r--r--support/src/android/support/test/internal/runner/junit4/AndroidJUnit4ClassRunner.java (renamed from androidtestlib/src/com/android/test/runner/junit4/AndroidJUnit4ClassRunner.java)8
-rw-r--r--support/src/android/support/test/internal/runner/junit4/NonExecutingJUnit4ClassRunner.java (renamed from androidtestlib/src/com/android/test/runner/junit4/NonExecutingJUnit4ClassRunner.java)2
-rw-r--r--support/src/android/support/test/internal/runner/junit4/package.html5
-rw-r--r--support/src/android/support/test/internal/runner/listener/CoverageListener.java (renamed from androidtestlib/src/com/android/test/runner/listener/CoverageListener.java)2
-rw-r--r--support/src/android/support/test/internal/runner/listener/DelayInjector.java (renamed from androidtestlib/src/com/android/test/runner/listener/DelayInjector.java)2
-rw-r--r--support/src/android/support/test/internal/runner/listener/InstrumentationResultPrinter.java (renamed from androidtestlib/src/com/android/test/runner/listener/InstrumentationResultPrinter.java)2
-rw-r--r--support/src/android/support/test/internal/runner/listener/InstrumentationRunListener.java (renamed from androidtestlib/src/com/android/test/runner/listener/InstrumentationRunListener.java)2
-rw-r--r--support/src/android/support/test/internal/runner/listener/LogRunListener.java (renamed from androidtestlib/src/com/android/test/runner/listener/LogRunListener.java)3
-rw-r--r--support/src/android/support/test/internal/runner/listener/SuiteAssignmentPrinter.java (renamed from androidtestlib/src/com/android/test/runner/listener/SuiteAssignmentPrinter.java)4
-rw-r--r--support/src/android/support/test/internal/runner/listener/package.html5
-rw-r--r--support/src/android/support/test/internal/runner/package.html5
-rw-r--r--support/src/android/support/test/runner/AndroidJUnitRunner.java (renamed from androidtestlib/src/com/android/test/runner/AndroidJUnitRunner.java)39
-rw-r--r--support/tests/.classpath (renamed from androidtestlib/tests/.classpath)9
-rw-r--r--support/tests/.gitignore (renamed from androidtestlib/tests/.gitignore)0
-rw-r--r--support/tests/.project (renamed from androidtestlib/tests/.project)6
-rw-r--r--support/tests/Android.mk (renamed from androidtestlib/tests/Android.mk)6
-rw-r--r--support/tests/AndroidManifest.xml (renamed from androidtestlib/tests/AndroidManifest.xml)2
-rw-r--r--support/tests/src/android/support/test/InstrumentationJUnit4Fixture.java (renamed from androidtestlib/tests/src/com/android/test/InstrumentationJUnit4Fixture.java)3
-rw-r--r--support/tests/src/android/support/test/InstrumentationJUnit4FixtureTest.java (renamed from androidtestlib/tests/src/com/android/test/InstrumentationJUnit4FixtureTest.java)3
-rw-r--r--support/tests/src/android/support/test/InstrumentationJUnit4Test.java (renamed from androidtestlib/tests/src/com/android/test/InstrumentationJUnit4Test.java)3
-rw-r--r--support/tests/src/android/support/test/MyAndroidTestCase.java (renamed from androidtestlib/tests/src/com/android/test/MyAndroidTestCase.java)2
-rw-r--r--support/tests/src/android/support/test/MyBundleTestCase.java (renamed from androidtestlib/tests/src/com/android/test/MyBundleTestCase.java)3
-rw-r--r--support/tests/src/android/support/test/MyInstrumentationTestCase.java (renamed from androidtestlib/tests/src/com/android/test/MyInstrumentationTestCase.java)2
-rw-r--r--support/tests/src/android/support/test/internal/runner/ClassPathScannerTest.java (renamed from androidtestlib/tests/src/com/android/test/runner/ClassPathScannerTest.java)11
-rw-r--r--support/tests/src/android/support/test/internal/runner/TestLoaderTest.java (renamed from androidtestlib/tests/src/com/android/test/runner/TestLoaderTest.java)4
-rw-r--r--support/tests/src/android/support/test/internal/runner/TestRequestBuilderTest.java (renamed from androidtestlib/tests/src/com/android/test/runner/TestRequestBuilderTest.java)8
-rw-r--r--support/tests/src/android/support/test/runner/AndroidJUnitRunnerTest.java (renamed from androidtestlib/tests/src/com/android/test/runner/AndroidJUnitRunnerTest.java)4
47 files changed, 216 insertions, 134 deletions
diff --git a/androidtestlib/Android.mk b/androidtestlib/Android.mk
deleted file mode 100644
index f6b7169..0000000
--- a/androidtestlib/Android.mk
+++ /dev/null
@@ -1,50 +0,0 @@
-# Copyright (C) 2012 The Android Open Source Project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-# http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-#
-#
-
-LOCAL_PATH := $(call my-dir)
-include $(CLEAR_VARS)
-
-LOCAL_SRC_FILES := $(call all-java-files-under, src)
-
-LOCAL_MODULE := android-test-lib
-
-LOCAL_MODULE_TAGS := optional
-
-LOCAL_SDK_VERSION := 8
-LOCAL_STATIC_JAVA_LIBRARIES := junit4-target
-
-include $(BUILD_STATIC_JAVA_LIBRARY)
-
-# ------------------------------------------------
-# build a version without bundled dependencies
-include $(CLEAR_VARS)
-
-LOCAL_SRC_FILES := $(call all-java-files-under, src)
-
-LOCAL_MODULE := android-test-lib-nodeps
-
-LOCAL_MODULE_TAGS := optional
-
-LOCAL_SDK_VERSION := 8
-LOCAL_JAVA_LIBRARIES := junit4-target
-
-include $(BUILD_STATIC_JAVA_LIBRARY)
-
-# -----------------------------------------------
-
-# Use the following include to make our test apk.
-include $(call all-makefiles-under,$(LOCAL_PATH))
-
diff --git a/androidtestlib/README b/androidtestlib/README
deleted file mode 100644
index 077a36b..0000000
--- a/androidtestlib/README
+++ /dev/null
@@ -1 +0,0 @@
-an currently experimental static library for running JUnit4 tests on Android.
diff --git a/support/Android.mk b/support/Android.mk
new file mode 100644
index 0000000..f0b1324
--- /dev/null
+++ b/support/Android.mk
@@ -0,0 +1,94 @@
+# Copyright (C) 2012 The Android Open Source Project
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+#
+
+LOCAL_PATH := $(call my-dir)
+include $(CLEAR_VARS)
+
+LOCAL_SRC_FILES := $(call all-java-files-under, src)
+
+LOCAL_MODULE := android-support-test
+
+LOCAL_MODULE_TAGS := optional
+
+LOCAL_SDK_VERSION := 8
+LOCAL_STATIC_JAVA_LIBRARIES := junit4-target
+
+include $(BUILD_STATIC_JAVA_LIBRARY)
+
+# ------------------------------------------------
+# build a version without bundled dependencies
+include $(CLEAR_VARS)
+
+LOCAL_SRC_FILES := $(call all-java-files-under, src)
+
+LOCAL_MODULE := android-support-test-nodeps
+
+LOCAL_MODULE_TAGS := optional
+
+LOCAL_SDK_VERSION := 8
+LOCAL_JAVA_LIBRARIES := junit4-target
+
+include $(BUILD_STATIC_JAVA_LIBRARY)
+
+# -----------------------------------------------
+# build a droiddoc package for integration in d.android.com
+include $(CLEAR_VARS)
+
+LOCAL_SRC_FILES := $(call all-java-files-under, src) \
+ $(call junit4_to_document, ../../../external/junit/src/org) \
+ $(call all-java-files-under, ../../../external/hamcrest/src)
+
+LOCAL_MODULE := android-support-test-docs
+LOCAL_MODULE_TAGS := optional
+LOCAL_MODULE_CLASS := JAVA_LIBRARIES
+LOCAL_JAVA_LIBRARIES := android-support-test
+LOCAL_SDK_VERSION := 8
+LOCAL_IS_HOST_MODULE := false
+LOCAL_DROIDDOC_CUSTOM_TEMPLATE_DIR := build/tools/droiddoc/templates-sdk
+
+LOCAL_DROIDDOC_OPTIONS := \
+ -hdf android.whichdoc online \
+ -hdf template.showLanguageMenu true
+
+include $(BUILD_DROIDDOC)
+
+# ----------------------------------------------
+# build a offline droiddoc package
+include $(CLEAR_VARS)
+
+LOCAL_SRC_FILES := $(call all-java-files-under, src) \
+ $(call all-java-files-under, ../../../external/junit/src/org) \
+ $(call all-java-files-under, ../../../external/hamcrest/src)
+
+LOCAL_MODULE := android-support-test-offline-docs
+LOCAL_MODULE_TAGS := optional
+LOCAL_MODULE_CLASS := JAVA_LIBRARIES
+LOCAL_JAVA_LIBRARIES := android-support-test
+LOCAL_SDK_VERSION := 8
+LOCAL_IS_HOST_MODULE := false
+LOCAL_DROIDDOC_CUSTOM_TEMPLATE_DIR := build/tools/droiddoc/templates-sdk
+
+LOCAL_DROIDDOC_OPTIONS := \
+ -offlinemode \
+ -hdf android.whichdoc offline \
+ -hdf template.showLanguageMenu true
+
+include $(BUILD_DROIDDOC)
+
+# ----------------------------------------------
+# Use the following include to make our test apk.
+include $(call all-makefiles-under,$(LOCAL_PATH))
+
diff --git a/androidtestlib/src/com/android/test/BundleTest.java b/support/src/android/support/test/BundleTest.java
index f989312..510a514 100644
--- a/androidtestlib/src/com/android/test/BundleTest.java
+++ b/support/src/android/support/test/BundleTest.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.os.Bundle;
diff --git a/androidtestlib/src/com/android/test/InjectBundle.java b/support/src/android/support/test/InjectBundle.java
index ee5e58e..4bc9170 100644
--- a/androidtestlib/src/com/android/test/InjectBundle.java
+++ b/support/src/android/support/test/InjectBundle.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.os.Bundle;
diff --git a/androidtestlib/src/com/android/test/InjectContext.java b/support/src/android/support/test/InjectContext.java
index a9749e3..3f8ad3b 100644
--- a/androidtestlib/src/com/android/test/InjectContext.java
+++ b/support/src/android/support/test/InjectContext.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.app.Instrumentation;
import android.content.Context;
diff --git a/androidtestlib/src/com/android/test/InjectInstrumentation.java b/support/src/android/support/test/InjectInstrumentation.java
index 949c142..a14596b 100644
--- a/androidtestlib/src/com/android/test/InjectInstrumentation.java
+++ b/support/src/android/support/test/InjectInstrumentation.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.app.Instrumentation;
import android.test.InstrumentationTestCase;
diff --git a/support/src/android/support/test/internal/package.html b/support/src/android/support/test/internal/package.html
new file mode 100644
index 0000000..1c9bf9d
--- /dev/null
+++ b/support/src/android/support/test/internal/package.html
@@ -0,0 +1,5 @@
+<html>
+<body>
+ {@hide}
+</body>
+</html>
diff --git a/androidtestlib/src/com/android/test/runner/AndroidRunnerBuilder.java b/support/src/android/support/test/internal/runner/AndroidRunnerBuilder.java
index e8c52a6..8b1008e 100644
--- a/androidtestlib/src/com/android/test/runner/AndroidRunnerBuilder.java
+++ b/support/src/android/support/test/internal/runner/AndroidRunnerBuilder.java
@@ -13,13 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
import android.app.Instrumentation;
import android.os.Bundle;
+import android.support.test.internal.runner.junit3.AndroidJUnit3Builder;
+import android.support.test.internal.runner.junit4.AndroidJUnit4Builder;
-import com.android.test.runner.junit3.AndroidJUnit3Builder;
-import com.android.test.runner.junit4.AndroidJUnit4Builder;
import org.junit.internal.builders.AllDefaultPossibilitiesBuilder;
import org.junit.runner.Runner;
diff --git a/androidtestlib/src/com/android/test/runner/ClassPathScanner.java b/support/src/android/support/test/internal/runner/ClassPathScanner.java
index 19ef3fe..300c7de 100644
--- a/androidtestlib/src/com/android/test/runner/ClassPathScanner.java
+++ b/support/src/android/support/test/internal/runner/ClassPathScanner.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
import dalvik.system.DexFile;
diff --git a/androidtestlib/src/com/android/test/runner/TestLoader.java b/support/src/android/support/test/internal/runner/TestLoader.java
index 4fe8c7e..a428a9d 100644
--- a/androidtestlib/src/com/android/test/runner/TestLoader.java
+++ b/support/src/android/support/test/internal/runner/TestLoader.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
import android.util.Log;
diff --git a/androidtestlib/src/com/android/test/runner/TestRequest.java b/support/src/android/support/test/internal/runner/TestRequest.java
index 5b15f84..ec390e9 100644
--- a/androidtestlib/src/com/android/test/runner/TestRequest.java
+++ b/support/src/android/support/test/internal/runner/TestRequest.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
import org.junit.runner.Request;
import org.junit.runner.notification.Failure;
diff --git a/androidtestlib/src/com/android/test/runner/TestRequestBuilder.java b/support/src/android/support/test/internal/runner/TestRequestBuilder.java
index 32e1295..eda78f0 100644
--- a/androidtestlib/src/com/android/test/runner/TestRequestBuilder.java
+++ b/support/src/android/support/test/internal/runner/TestRequestBuilder.java
@@ -13,20 +13,20 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
import android.app.Instrumentation;
import android.os.Bundle;
+import android.support.test.internal.runner.ClassPathScanner.ChainedClassNameFilter;
+import android.support.test.internal.runner.ClassPathScanner.ExcludePackageNameFilter;
+import android.support.test.internal.runner.ClassPathScanner.ExternalClassNameFilter;
+import android.support.test.internal.runner.ClassPathScanner.InclusivePackageNameFilter;
import android.test.suitebuilder.annotation.LargeTest;
import android.test.suitebuilder.annotation.MediumTest;
import android.test.suitebuilder.annotation.SmallTest;
import android.test.suitebuilder.annotation.Suppress;
import android.util.Log;
-import com.android.test.runner.ClassPathScanner.ChainedClassNameFilter;
-import com.android.test.runner.ClassPathScanner.ExcludePackageNameFilter;
-import com.android.test.runner.ClassPathScanner.ExternalClassNameFilter;
-import com.android.test.runner.ClassPathScanner.InclusivePackageNameFilter;
import org.junit.runner.Computer;
import org.junit.runner.Description;
diff --git a/androidtestlib/src/com/android/test/runner/junit3/AndroidJUnit3Builder.java b/support/src/android/support/test/internal/runner/junit3/AndroidJUnit3Builder.java
index e20f28a..7bc6369 100644
--- a/androidtestlib/src/com/android/test/runner/junit3/AndroidJUnit3Builder.java
+++ b/support/src/android/support/test/internal/runner/junit3/AndroidJUnit3Builder.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit3;
+package android.support.test.internal.runner.junit3;
import android.app.Instrumentation;
import android.os.Bundle;
@@ -66,7 +66,7 @@ public class AndroidJUnit3Builder extends RunnerBuilder {
}
boolean isBundleTest(Class<?> testClass) {
- return com.android.test.BundleTest.class.isAssignableFrom(testClass);
+ return android.support.test.BundleTest.class.isAssignableFrom(testClass);
}
}
diff --git a/androidtestlib/src/com/android/test/runner/junit3/AndroidJUnit3ClassRunner.java b/support/src/android/support/test/internal/runner/junit3/AndroidJUnit3ClassRunner.java
index 418a80b..a208702 100644
--- a/androidtestlib/src/com/android/test/runner/junit3/AndroidJUnit3ClassRunner.java
+++ b/support/src/android/support/test/internal/runner/junit3/AndroidJUnit3ClassRunner.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit3;
+package android.support.test.internal.runner.junit3;
import android.app.Instrumentation;
import android.os.Bundle;
diff --git a/androidtestlib/src/com/android/test/runner/junit3/AndroidTestSuite.java b/support/src/android/support/test/internal/runner/junit3/AndroidTestSuite.java
index e1a90c3..d07549b 100644
--- a/androidtestlib/src/com/android/test/runner/junit3/AndroidTestSuite.java
+++ b/support/src/android/support/test/internal/runner/junit3/AndroidTestSuite.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit3;
+package android.support.test.internal.runner.junit3;
import junit.framework.Test;
import junit.framework.TestResult;
@@ -24,10 +24,10 @@ import org.junit.Ignore;
import android.app.Instrumentation;
import android.content.Context;
import android.os.Bundle;
+import android.support.test.BundleTest;
import android.test.AndroidTestCase;
import android.test.InstrumentationTestCase;
-import com.android.test.BundleTest;
/**
* A {@link TestSuite} used to pass {@link Context} and {@link Instrumentation} references to child
diff --git a/androidtestlib/src/com/android/test/runner/junit3/NoExecTestResult.java b/support/src/android/support/test/internal/runner/junit3/NoExecTestResult.java
index 5ccf9ef..5c2cb08 100644
--- a/androidtestlib/src/com/android/test/runner/junit3/NoExecTestResult.java
+++ b/support/src/android/support/test/internal/runner/junit3/NoExecTestResult.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit3;
+package android.support.test.internal.runner.junit3;
import junit.framework.TestCase;
import junit.framework.TestResult;
diff --git a/androidtestlib/src/com/android/test/runner/junit3/NonExecutingJUnit3ClassRunner.java b/support/src/android/support/test/internal/runner/junit3/NonExecutingJUnit3ClassRunner.java
index 0bc0b74..7405870 100644
--- a/androidtestlib/src/com/android/test/runner/junit3/NonExecutingJUnit3ClassRunner.java
+++ b/support/src/android/support/test/internal/runner/junit3/NonExecutingJUnit3ClassRunner.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit3;
+package android.support.test.internal.runner.junit3;
import junit.framework.TestResult;
diff --git a/support/src/android/support/test/internal/runner/junit3/package.html b/support/src/android/support/test/internal/runner/junit3/package.html
new file mode 100644
index 0000000..1c9bf9d
--- /dev/null
+++ b/support/src/android/support/test/internal/runner/junit3/package.html
@@ -0,0 +1,5 @@
+<html>
+<body>
+ {@hide}
+</body>
+</html>
diff --git a/androidtestlib/src/com/android/test/runner/junit4/AndroidJUnit4Builder.java b/support/src/android/support/test/internal/runner/junit4/AndroidJUnit4Builder.java
index 31881dd..356d17b 100644
--- a/androidtestlib/src/com/android/test/runner/junit4/AndroidJUnit4Builder.java
+++ b/support/src/android/support/test/internal/runner/junit4/AndroidJUnit4Builder.java
@@ -13,13 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit4;
+package android.support.test.internal.runner.junit4;
import android.app.Instrumentation;
import android.os.Bundle;
+import android.support.test.InjectContext;
+import android.support.test.InjectInstrumentation;
-import com.android.test.InjectContext;
-import com.android.test.InjectInstrumentation;
import org.junit.runner.Runner;
import org.junit.runners.model.RunnerBuilder;
diff --git a/androidtestlib/src/com/android/test/runner/junit4/AndroidJUnit4ClassRunner.java b/support/src/android/support/test/internal/runner/junit4/AndroidJUnit4ClassRunner.java
index 92bac8a..d263b22 100644
--- a/androidtestlib/src/com/android/test/runner/junit4/AndroidJUnit4ClassRunner.java
+++ b/support/src/android/support/test/internal/runner/junit4/AndroidJUnit4ClassRunner.java
@@ -13,16 +13,16 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit4;
+package android.support.test.internal.runner.junit4;
import android.app.Instrumentation;
import android.content.Context;
import android.os.Bundle;
+import android.support.test.InjectBundle;
+import android.support.test.InjectContext;
+import android.support.test.InjectInstrumentation;
import android.util.Log;
-import com.android.test.InjectBundle;
-import com.android.test.InjectContext;
-import com.android.test.InjectInstrumentation;
import org.junit.runners.BlockJUnit4ClassRunner;
import org.junit.runners.model.FrameworkField;
diff --git a/androidtestlib/src/com/android/test/runner/junit4/NonExecutingJUnit4ClassRunner.java b/support/src/android/support/test/internal/runner/junit4/NonExecutingJUnit4ClassRunner.java
index b388da0..dd4e989 100644
--- a/androidtestlib/src/com/android/test/runner/junit4/NonExecutingJUnit4ClassRunner.java
+++ b/support/src/android/support/test/internal/runner/junit4/NonExecutingJUnit4ClassRunner.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.junit4;
+package android.support.test.internal.runner.junit4;
import org.junit.runners.BlockJUnit4ClassRunner;
import org.junit.runners.model.FrameworkMethod;
diff --git a/support/src/android/support/test/internal/runner/junit4/package.html b/support/src/android/support/test/internal/runner/junit4/package.html
new file mode 100644
index 0000000..1c9bf9d
--- /dev/null
+++ b/support/src/android/support/test/internal/runner/junit4/package.html
@@ -0,0 +1,5 @@
+<html>
+<body>
+ {@hide}
+</body>
+</html>
diff --git a/androidtestlib/src/com/android/test/runner/listener/CoverageListener.java b/support/src/android/support/test/internal/runner/listener/CoverageListener.java
index 4b36ea3..cd1e63e 100644
--- a/androidtestlib/src/com/android/test/runner/listener/CoverageListener.java
+++ b/support/src/android/support/test/internal/runner/listener/CoverageListener.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.listener;
+package android.support.test.internal.runner.listener;
import android.app.Instrumentation;
import android.os.Bundle;
diff --git a/androidtestlib/src/com/android/test/runner/listener/DelayInjector.java b/support/src/android/support/test/internal/runner/listener/DelayInjector.java
index b092029..b2a2e9f 100644
--- a/androidtestlib/src/com/android/test/runner/listener/DelayInjector.java
+++ b/support/src/android/support/test/internal/runner/listener/DelayInjector.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.listener;
+package android.support.test.internal.runner.listener;
import android.util.Log;
diff --git a/androidtestlib/src/com/android/test/runner/listener/InstrumentationResultPrinter.java b/support/src/android/support/test/internal/runner/listener/InstrumentationResultPrinter.java
index df392e2..65b4edf 100644
--- a/androidtestlib/src/com/android/test/runner/listener/InstrumentationResultPrinter.java
+++ b/support/src/android/support/test/internal/runner/listener/InstrumentationResultPrinter.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.listener;
+package android.support.test.internal.runner.listener;
import android.app.Instrumentation;
import android.os.Bundle;
diff --git a/androidtestlib/src/com/android/test/runner/listener/InstrumentationRunListener.java b/support/src/android/support/test/internal/runner/listener/InstrumentationRunListener.java
index e9370af..f584677 100644
--- a/androidtestlib/src/com/android/test/runner/listener/InstrumentationRunListener.java
+++ b/support/src/android/support/test/internal/runner/listener/InstrumentationRunListener.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.listener;
+package android.support.test.internal.runner.listener;
import android.app.Instrumentation;
import android.os.Bundle;
diff --git a/androidtestlib/src/com/android/test/runner/listener/LogRunListener.java b/support/src/android/support/test/internal/runner/listener/LogRunListener.java
index 9f10b60..9e27c4a 100644
--- a/androidtestlib/src/com/android/test/runner/listener/LogRunListener.java
+++ b/support/src/android/support/test/internal/runner/listener/LogRunListener.java
@@ -13,11 +13,10 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner.listener;
+package android.support.test.internal.runner.listener;
import android.util.Log;
-import org.junit.internal.AssumptionViolatedException;
import org.junit.runner.Description;
import org.junit.runner.Result;
import org.junit.runner.notification.Failure;
diff --git a/androidtestlib/src/com/android/test/runner/listener/SuiteAssignmentPrinter.java b/support/src/android/support/test/internal/runner/listener/SuiteAssignmentPrinter.java
index ac4aa2c..c636f7f 100644
--- a/androidtestlib/src/com/android/test/runner/listener/SuiteAssignmentPrinter.java
+++ b/support/src/android/support/test/internal/runner/listener/SuiteAssignmentPrinter.java
@@ -14,9 +14,9 @@
* limitations under the License.
*/
-package com.android.test.runner.listener;
+package android.support.test.internal.runner.listener;
-import com.android.test.runner.TestRequestBuilder;
+import android.support.test.internal.runner.TestRequestBuilder;
import org.junit.runner.Description;
import org.junit.runner.notification.Failure;
diff --git a/support/src/android/support/test/internal/runner/listener/package.html b/support/src/android/support/test/internal/runner/listener/package.html
new file mode 100644
index 0000000..1c9bf9d
--- /dev/null
+++ b/support/src/android/support/test/internal/runner/listener/package.html
@@ -0,0 +1,5 @@
+<html>
+<body>
+ {@hide}
+</body>
+</html>
diff --git a/support/src/android/support/test/internal/runner/package.html b/support/src/android/support/test/internal/runner/package.html
new file mode 100644
index 0000000..1c9bf9d
--- /dev/null
+++ b/support/src/android/support/test/internal/runner/package.html
@@ -0,0 +1,5 @@
+<html>
+<body>
+ {@hide}
+</body>
+</html>
diff --git a/androidtestlib/tests/.classpath b/support/tests/.classpath
index 99b9c55..487c349 100644
--- a/androidtestlib/tests/.classpath
+++ b/support/tests/.classpath
@@ -1,16 +1,17 @@
<?xml version="1.0" encoding="UTF-8"?>
<classpath>
- <classpathentry kind="src" path="src"/>
- <classpathentry kind="src" path="gen"/>
<classpathentry kind="src" path="dexmaker-java-src"/>
<classpathentry kind="src" path="dexmaker-dx-src"/>
<classpathentry kind="src" path="hamcrest-src"/>
<classpathentry kind="src" path="junit4-src"/>
- <classpathentry kind="src" path="android-test-lib-src"/>
<classpathentry kind="src" path="objenesis-src"/>
<classpathentry kind="src" path="mockito-src"/>
<classpathentry kind="src" path="dexmaker-mockito"/>
+ <classpathentry kind="src" path="android-support-test-src"/>
<classpathentry kind="con" path="com.android.ide.eclipse.adt.ANDROID_FRAMEWORK"/>
- <classpathentry kind="con" path="com.android.ide.eclipse.adt.LIBRARIES"/>
+ <classpathentry exported="true" kind="con" path="com.android.ide.eclipse.adt.LIBRARIES"/>
+ <classpathentry exported="true" kind="con" path="com.android.ide.eclipse.adt.DEPENDENCIES"/>
+ <classpathentry kind="src" path="src"/>
+ <classpathentry kind="src" path="gen"/>
<classpathentry kind="output" path="bin/classes"/>
</classpath>
diff --git a/androidtestlib/tests/.gitignore b/support/tests/.gitignore
index 4f62b84..4f62b84 100644
--- a/androidtestlib/tests/.gitignore
+++ b/support/tests/.gitignore
diff --git a/androidtestlib/tests/.project b/support/tests/.project
index e4e4c5e..8070e85 100644
--- a/androidtestlib/tests/.project
+++ b/support/tests/.project
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<projectDescription>
- <name>AndroidTestLibTests</name>
+ <name>AndroidSupportTestTests</name>
<comment></comment>
<projects>
</projects>
@@ -32,9 +32,9 @@
</natures>
<linkedResources>
<link>
- <name>android-test-lib-src</name>
+ <name>android-support-test-src</name>
<type>2</type>
- <locationURI>ANDROID_TOP/frameworks/testing/androidtestlib/src</locationURI>
+ <locationURI>ANDROID_TOP/frameworks/testing/support/src</locationURI>
</link>
<link>
<name>dexmaker-dx-src</name>
diff --git a/androidtestlib/tests/Android.mk b/support/tests/Android.mk
index fa27121..02cbe1a 100644
--- a/androidtestlib/tests/Android.mk
+++ b/support/tests/Android.mk
@@ -14,21 +14,21 @@
#
#
-# build unit tests for android-test-lib
+# build unit tests for android-support-test
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
LOCAL_SRC_FILES := $(call all-java-files-under, src)
-LOCAL_PACKAGE_NAME := AndroidTestLibTests
+LOCAL_PACKAGE_NAME := AndroidSupportTestTests
LOCAL_MODULE_TAGS := tests
# SDK 10 needed for mockito/objnesis. Otherwise 8 would work
LOCAL_SDK_VERSION := 10
-LOCAL_STATIC_JAVA_LIBRARIES := android-test-lib mockito-target dexmaker
+LOCAL_STATIC_JAVA_LIBRARIES := android-support-test mockito-target dexmaker
LOCAL_PROGUARD_ENABLED := disabled
diff --git a/androidtestlib/tests/AndroidManifest.xml b/support/tests/AndroidManifest.xml
index c8c181e..21744c4 100644
--- a/androidtestlib/tests/AndroidManifest.xml
+++ b/support/tests/AndroidManifest.xml
@@ -20,7 +20,7 @@
<application>
</application>
- <instrumentation android:name="com.android.test.runner.AndroidJUnitRunner"
+ <instrumentation android:name="android.support.test.runner.AndroidJUnitRunner"
android:targetPackage="com.android.testlib.tests"
android:label="Unit Tests for testlib."/>
diff --git a/androidtestlib/tests/src/com/android/test/InstrumentationJUnit4Fixture.java b/support/tests/src/android/support/test/InstrumentationJUnit4Fixture.java
index 8fa70ac..2164533 100644
--- a/androidtestlib/tests/src/com/android/test/InstrumentationJUnit4Fixture.java
+++ b/support/tests/src/android/support/test/InstrumentationJUnit4Fixture.java
@@ -13,9 +13,10 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.app.Instrumentation;
+import android.support.test.InjectInstrumentation;
import android.util.Log;
/**
diff --git a/androidtestlib/tests/src/com/android/test/InstrumentationJUnit4FixtureTest.java b/support/tests/src/android/support/test/InstrumentationJUnit4FixtureTest.java
index c4ffcf2..98849c8 100644
--- a/androidtestlib/tests/src/com/android/test/InstrumentationJUnit4FixtureTest.java
+++ b/support/tests/src/android/support/test/InstrumentationJUnit4FixtureTest.java
@@ -13,8 +13,9 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
+import android.support.test.InjectInstrumentation;
import android.util.Log;
import junit.framework.Assert;
diff --git a/androidtestlib/tests/src/com/android/test/InstrumentationJUnit4Test.java b/support/tests/src/android/support/test/InstrumentationJUnit4Test.java
index de0dd35..2bab63e 100644
--- a/androidtestlib/tests/src/com/android/test/InstrumentationJUnit4Test.java
+++ b/support/tests/src/android/support/test/InstrumentationJUnit4Test.java
@@ -13,9 +13,10 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.app.Instrumentation;
+import android.support.test.InjectInstrumentation;
import android.util.Log;
import junit.framework.Assert;
diff --git a/androidtestlib/tests/src/com/android/test/MyAndroidTestCase.java b/support/tests/src/android/support/test/MyAndroidTestCase.java
index f48337e..8b6d02b 100644
--- a/androidtestlib/tests/src/com/android/test/MyAndroidTestCase.java
+++ b/support/tests/src/android/support/test/MyAndroidTestCase.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.content.Context;
import android.test.AndroidTestCase;
diff --git a/androidtestlib/tests/src/com/android/test/MyBundleTestCase.java b/support/tests/src/android/support/test/MyBundleTestCase.java
index 7ed0fd4..d1393c5 100644
--- a/androidtestlib/tests/src/com/android/test/MyBundleTestCase.java
+++ b/support/tests/src/android/support/test/MyBundleTestCase.java
@@ -13,10 +13,11 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import junit.framework.TestCase;
import android.os.Bundle;
+import android.support.test.BundleTest;
import android.util.Log;
/**
diff --git a/androidtestlib/tests/src/com/android/test/MyInstrumentationTestCase.java b/support/tests/src/android/support/test/MyInstrumentationTestCase.java
index 27796e7..dac4ead 100644
--- a/androidtestlib/tests/src/com/android/test/MyInstrumentationTestCase.java
+++ b/support/tests/src/android/support/test/MyInstrumentationTestCase.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test;
+package android.support.test;
import android.app.Instrumentation;
import android.test.InstrumentationTestCase;
diff --git a/androidtestlib/tests/src/com/android/test/runner/ClassPathScannerTest.java b/support/tests/src/android/support/test/internal/runner/ClassPathScannerTest.java
index ade985c..f238bd6 100644
--- a/androidtestlib/tests/src/com/android/test/runner/ClassPathScannerTest.java
+++ b/support/tests/src/android/support/test/internal/runner/ClassPathScannerTest.java
@@ -13,14 +13,15 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
import android.content.Context;
+import android.support.test.InjectContext;
+import android.support.test.internal.runner.ClassPathScanner;
+import android.support.test.internal.runner.ClassPathScanner.ExcludePackageNameFilter;
+import android.support.test.internal.runner.ClassPathScanner.ExternalClassNameFilter;
+import android.support.test.internal.runner.ClassPathScanner.InclusivePackageNameFilter;
-import com.android.test.InjectContext;
-import com.android.test.runner.ClassPathScanner.ExcludePackageNameFilter;
-import com.android.test.runner.ClassPathScanner.ExternalClassNameFilter;
-import com.android.test.runner.ClassPathScanner.InclusivePackageNameFilter;
import dalvik.system.DexFile;
diff --git a/androidtestlib/tests/src/com/android/test/runner/TestLoaderTest.java b/support/tests/src/android/support/test/internal/runner/TestLoaderTest.java
index 34cadc1..dbe0dd1 100644
--- a/androidtestlib/tests/src/com/android/test/runner/TestLoaderTest.java
+++ b/support/tests/src/android/support/test/internal/runner/TestLoaderTest.java
@@ -13,7 +13,9 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
+
+import android.support.test.internal.runner.TestLoader;
import junit.framework.Assert;
import junit.framework.TestCase;
diff --git a/androidtestlib/tests/src/com/android/test/runner/TestRequestBuilderTest.java b/support/tests/src/android/support/test/internal/runner/TestRequestBuilderTest.java
index f20c35e..58b8c0d 100644
--- a/androidtestlib/tests/src/com/android/test/runner/TestRequestBuilderTest.java
+++ b/support/tests/src/android/support/test/internal/runner/TestRequestBuilderTest.java
@@ -13,16 +13,18 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.internal.runner;
import android.app.Instrumentation;
import android.os.Bundle;
+import android.support.test.InjectBundle;
+import android.support.test.InjectInstrumentation;
+import android.support.test.internal.runner.TestRequest;
+import android.support.test.internal.runner.TestRequestBuilder;
import android.test.suitebuilder.annotation.MediumTest;
import android.test.suitebuilder.annotation.SmallTest;
import android.test.suitebuilder.annotation.Suppress;
-import com.android.test.InjectBundle;
-import com.android.test.InjectInstrumentation;
import junit.framework.TestCase;
diff --git a/androidtestlib/tests/src/com/android/test/runner/AndroidJUnitRunnerTest.java b/support/tests/src/android/support/test/runner/AndroidJUnitRunnerTest.java
index 441c4f0..7952980 100644
--- a/androidtestlib/tests/src/com/android/test/runner/AndroidJUnitRunnerTest.java
+++ b/support/tests/src/android/support/test/runner/AndroidJUnitRunnerTest.java
@@ -13,10 +13,12 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.runner;
import android.content.Context;
import android.os.Bundle;
+import android.support.test.internal.runner.TestRequestBuilder;
+import android.support.test.runner.AndroidJUnitRunner;
import org.junit.Before;
import org.junit.Test;
diff --git a/androidtestlib/src/com/android/test/runner/AndroidJUnitRunner.java b/support/src/android/support/test/runner/AndroidJUnitRunner.java
index 83e6db1..cb62f4e 100644
--- a/androidtestlib/src/com/android/test/runner/AndroidJUnitRunner.java
+++ b/support/src/android/support/test/runner/AndroidJUnitRunner.java
@@ -14,22 +14,24 @@
* limitations under the License.
*/
-package com.android.test.runner;
+package android.support.test.runner;
import android.app.Activity;
import android.app.Instrumentation;
import android.os.Bundle;
import android.os.Debug;
import android.os.Looper;
+import android.support.test.internal.runner.TestRequest;
+import android.support.test.internal.runner.TestRequestBuilder;
+import android.support.test.internal.runner.listener.CoverageListener;
+import android.support.test.internal.runner.listener.DelayInjector;
+import android.support.test.internal.runner.listener.InstrumentationResultPrinter;
+import android.support.test.internal.runner.listener.InstrumentationRunListener;
+import android.support.test.internal.runner.listener.LogRunListener;
+import android.support.test.internal.runner.listener.SuiteAssignmentPrinter;
import android.test.suitebuilder.annotation.LargeTest;
import android.util.Log;
-import com.android.test.runner.listener.CoverageListener;
-import com.android.test.runner.listener.DelayInjector;
-import com.android.test.runner.listener.InstrumentationResultPrinter;
-import com.android.test.runner.listener.InstrumentationRunListener;
-import com.android.test.runner.listener.LogRunListener;
-import com.android.test.runner.listener.SuiteAssignmentPrinter;
import org.junit.internal.TextListener;
import org.junit.runner.JUnitCore;
@@ -54,32 +56,33 @@ import java.util.List;
* <p/>
* Write JUnit3 style {@link junit.framework.TestCase}s and/or JUnit4 style
* {@link org.junit.Test}s that perform tests against the classes in your package.
* Make use of the {@link com.android.test.InjectContext} and
* {@link com.android.test.InjectInstrumentation} annotations if needed.
* <p/>
* In an appropriate AndroidManifest.xml, define an instrumentation with android:name set to
* {@link com.android.test.runner.AndroidJUnitRunner} and the appropriate android:targetPackage set.
* <p/>
* Execution options:
* <p/>
* <b>Running all tests:</b> adb shell am instrument -w
- * com.android.foo/com.android.test.runner.AndroidJUnitRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <p/>
* <b>Running all tests in a class:</b> adb shell am instrument -w
* -e class com.android.foo.FooTest
- * com.android.foo/com.android.test.runner.AndroidJUnitRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <p/>
* <b>Running a single test:</b> adb shell am instrument -w
* -e class com.android.foo.FooTest#testFoo
- * com.android.foo/com.android.test.runner.AndroidJUnitRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <p/>
* <b>Running all tests in multiple classes:</b> adb shell am instrument -w
* -e class com.android.foo.FooTest,com.android.foo.TooTest
- * com.android.foo/com.android.test.runner.AndroidJUnitRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <p/>
* <b>Running all tests in a java package:</b> adb shell am instrument -w
* -e package com.android.foo.bar
- * com.android.foo/com.android.test.runner.AndroidJUnitRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <b>To debug your tests, set a break point in your code and pass:</b>
* -e debug true
* <p/>
@@ -88,11 +91,11 @@ import java.util.List;
* {@link android.test.suitebuilder.annotation.MediumTest} or
* {@link android.test.suitebuilder.annotation.LargeTest}:</b>
* adb shell am instrument -w -e size [small|medium|large]
- * com.android.foo/android.test.InstrumentationTestRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <p/>
* <b>Filter test run to tests with given annotation:</b> adb shell am instrument -w
* -e annotation com.android.foo.MyAnnotation
- * com.android.foo/android.test.InstrumentationTestRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <p/>
* If used with other options, the resulting test run will contain the intersection of the two
* options.
@@ -101,7 +104,7 @@ import java.util.List;
* <p/>
* <b>Filter test run to tests <i>without</i> given annotation:</b> adb shell am instrument -w
* -e notAnnotation com.android.foo.MyAnnotation
- * com.android.foo/android.test.InstrumentationTestRunner
+ * com.android.foo/android.support.test.runner.AndroidJUnitRunner
* <p/>
* As above, if used with other options, the resulting test run will contain the intersection of
* the two options.
@@ -54,32 +56,33 @@ import java.util.List;
* Write JUnit3 style {@link junit.framework.TestCase}s and/or JUnit4 style
* {@link org.junit.Test}s that perform tests against the classes in your package.
- * Make use of the {@link com.android.test.InjectContext} and
- * {@link com.android.test.InjectInstrumentation} annotations if needed.
+ * Make use of the {@link android.support.test.InjectContext} and
+ * {@link android.support.test.InjectInstrumentation} annotations if needed.
* <p/>
* In an appropriate AndroidManifest.xml, define an instrumentation with android:name set to
@@ -54,32 +56,33 @@ import java.util.List;
* <p/>
* In an appropriate AndroidManifest.xml, define an instrumentation with android:name set to
- * {@link com.android.test.runner.AndroidJUnitRunner} and the appropriate android:targetPackage set.
+ * {@link android.support.test.runner.AndroidJUnitRunner} and the appropriate android:targetPackage
+ * set.
* <p/>
* Execution options: